EasyConvert class

Converte um campo inteiro OU os valores de um Map< K,V >.

  • fromJson/toJson: aplicados ao CAMPO inteiro (ex.: DateTime <-> epoch)
  • valueFromJson/valueToJson: aplicados a CADA VALOR de Map< K,V >

Constructors

EasyConvert({Function? fromJson, Function? toJson, Function? valueFromJson, Function? valueToJson})
const

Properties

fromJson Function?
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
toJson Function?
final
valueFromJson Function?
final
valueToJson Function?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited