EasyKey class

Anota um campo para configurar como ele será serializado.

Constructors

EasyKey({String? name, bool? includeIfNull, Object? fallback, Object? itemFallback, String? enumFallback})
const

Properties

enumFallback String?
Para ENUMs: nome do valor (byName) a usar como fallback quando houver erro em SAFE. Ex.: enumFallback: 'viewer'
final
fallback Object?
Fallback para o CAMPO quando houver erro em SAFE. Ex.: int -> 42, String -> 'n/a', bool -> true, double -> 3.14, DateTime -> '2024-01-01T00:00:00Z' (string ISO)
final
hashCode int
The hash code for this object.
no setterinherited
includeIfNull bool?
Sobrepõe o comportamento de EasyJson.includeIfNull para este campo. Se true, o campo será incluído no JSON mesmo se for nulo. Se false, o campo será omitido do JSON se for nulo. Se não for definido (nulo), o padrão da classe em @EasyJson será usado.
final
itemFallback Object?
Para LISTAS de primitivos/enum: fallback do ITEM quando houver erro em SAFE. Ex.: itemFallback: 0, '' etc.
final
name String?
O nome da chave que este campo terá no JSON.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited