EasyMapKey class
Define como coagir a CHAVE do Map< K,V >, quando o JSON vem com string/num.
Ex.: @EasyMapKey(type: EasyMapKeyType.int) JSON: {"1": "Ana", "2":"Bia"} => Map< int,String > {1:"Ana", 2:"Bia"}
Constructors
- EasyMapKey({required EasyMapKeyType type})
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- type → EasyMapKeyType
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited