EasyPath class
Define um caminho aninhado para ler o valor do JSON.
Ex.: @EasyPath('client.address.city') fará a leitura em json'address''city'.
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited