EasyJson class
Marca uma classe para a geração de código de serialização JSON.
Constructors
Properties
- caseStyle → CaseStyle?
-
Estilo de chave para campos sem
nameexplícito.final - fromJson → bool
-
Se
false, os métodos de desserialização (fromJson, fromJsonSafe, validate) não serão gerados.final - hashCode → int
-
The hash code for this object.
no setterinherited
- includeIfNull → bool
-
O comportamento padrão para a inclusão de campos nulos no método toJson().
Se
false(padrão), campos com valor nulo serão omitidos do JSON. Pode ser sobreposto por@EasyKey(includeIfNull: ...).final - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- toJson → bool
-
Se
false, os métodos de serialização (toJson) e o mixin não serão gerados.final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited