EasyUnion class
Define que esta classe é polimórfica e atua como um roteador para subclasses.
Constructors
Properties
- discriminator → String
-
O nome do campo no JSON que determina o tipo.
final
- fallback → Type?
-
Tipo de fallback opcional. Se a chave não existir ou for desconhecida,
o gerador usará este tipo. Se for null, o comportamento padrão será falhar
no
fromJsonnormal, e retornarnull(se possível) nofromJsonSafe.final - hashCode → int
-
The hash code for this object.
no setterinherited
-
mapping
→ Map<
String, Type> -
Mapa relacionando o valor da string no JSON para o Tipo Dart correspondente.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited